Learn R Programming

galamm (version 0.3.0)

gfam: Grouped families

Description

This function is inspired by a function of the same name in the mgcv package woodGeneralizedAdditiveModels2017galamm, and supports setting up mixed response type models. When using this function, the response variable must be supported as a two-column matrix, in which the first column contains the response and the second column contains an index mapping the response to the list elements provided in the argument fl to this function.

Usage

gfam(fl)

Value

An object of class "galamm_extended_family".

Arguments

fl

A list of families. Currently gaussian, binomial, and poisson with canonical link functions are supported.

References

See Also

Other modeling functions: galamm(), galammObject, s(), t2()