Mixed response dataset with one set of normally distributed responses and one set of binomially distributed responses. The normally distributed response follow two different residual standard deviations.
mresp_hscedmresp_hsced A data frame with 4000 rows and 5 columns:
Subject ID.
Predictor variable.
Matrix whose first column is the response and whose second column equals 1 if the observation is conditionally normally distributed and 2 if the observation is conditionally binomially distributed.
Factor variable which equals "a" for the normally distributed responses and "b" for the binomially distributed response (with 1 trial).
Grouping variable denoting which of the two residual standard deviations apply. Only relevant for the normally distributed responses.
Dummy variable indicating whether the observation on the given line is normally (Gaussian) distributed or not.
Other datasets:
cognition,
diet,
epilep,
hsced,
latent_covariates,
latent_covariates_long,
lifespan,
mresp