Longitudinal epilepsy data from leppikControlledStudyProgabide1987;textualgalamm. This documentation is based on Chapter 11.3 of skrondalGeneralizedLatentVariable2004;textualgalamm, where the dataset is used.
epilepepilep A data frame with 236 rows and 7 columns:
Subject ID.
Number of seizures.
Dummy variable for treatment group.
Time at visit.
Dummy for visit 4.
Logarithm of age.
Logarithm of a quarter of the number of seizures in the eight weeks preceding entry into the trial.
Other datasets:
cognition,
diet,
hsced,
latent_covariates,
latent_covariates_long,
lifespan,
mresp,
mresp_hsced