AICtab a table of model fit measures, returned by
llikAIC.
call the matched call used when fitting the model.
fixef a matrix with fixed effect estimated, returned by
fixef.
gam List containing information about smooth terms in the model. If
no smooth terms are contained in the model, then it is a list of length
zero.
model a list with various elements related to the model setup and
fit. See ?galamm for details.
parameters A list object with model parameters and related
information. See ?galamm for details.
Lambda An object containing the estimated factor loadings. Returned
from factor_loadings.galamm. If there are no estimated factor
loadings, then this object is NULL.
random_effects a list containing the random effects.
See ?galamm for details.
VarCorr An object of class VarCorr.galamm, returned from
VarCorr.galamm.
weights An object containing information about estimated variance
functions, when there are heteroscedastic residuals. Otherwise the object
is NULL.